@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2017-2023, Intel Corporation
+* Copyright (c) 2017-2024, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -123,7 +123,7 @@ typedef enum _CODEC_PICTURE_FLAG
     PICTURE_INTERLACED_FRAME        = 0x08,
     PICTURE_SHORT_TERM_REFERENCE    = 0x10,
     PICTURE_LONG_TERM_REFERENCE     = 0x20,
-    PICTURE_RESERVED0               = 0x40,
+    PICTURE_UNAVAILABLE_FRAME       = 0x40,
     PICTURE_INVALID                 = 0x80,
     PICTURE_RESIZE                  = 0xF0,
     PICTURE_MAX_7BITS               = 0xFF
@@ -170,6 +170,7 @@ enum REFLIST
 //!
 enum CODECHAL_MODE
 {
+    CODECHAL_DECODE_MODE_BEGIN              = 0,
     CODECHAL_DECODE_MODE_MPEG2IDCT          = 0,
     CODECHAL_DECODE_MODE_MPEG2VLD           = 1,
     CODECHAL_DECODE_MODE_VC1IT              = 2,
@@ -184,23 +185,23 @@ enum CODECHAL_MODE
     CODECHAL_DECODE_MODE_MVCVLD             = 11,   // Needed for CP. Not in use by Codec HAL.
     CODECHAL_DECODE_MODE_VP9VLD             = 12,
     CODECHAL_DECODE_MODE_CENC               = 13,   // Only for getting HuC-based DRM command size. Not an actual mode.
-    CODECHAL_DECODE_MODE_RESERVED0          = 14,
-    CODECHAL_NUM_DECODE_MODES               = 15,
+    CODECHAL_DECODE_MODE_VVCVLD             = 14,
+    CODECHAL_DECODE_MODE_RESERVED1          = 15,
+    CODECHAL_DECODE_MODE_RESERVED2          = 16,
+    CODECHAL_DECODE_MODE_END                = 17,
 
-    CODECHAL_ENCODE_MODE_AVC                = 16,   // Must be a power of 2 to match perf report expectations
-    CODECHAL_ENCODE_MODE_MPEG2              = 18,
-    CODECHAL_ENCODE_MODE_VP8                = 19,
-    CODECHAL_ENCODE_MODE_JPEG               = 20,
-    CODECHAL_ENCODE_MODE_HEVC               = 22,
-    CODECHAL_ENCODE_MODE_VP9                = 23,
-    CODECHAL_ENCODE_MODE_AV1                = 24,
-    CODECHAL_NUM_ENCODE_MODES               = 8,
-
-    CODECHAL_Rsvd                           = 25,
-    CODECHAL_NUM_MODES                      = 26,   // Use the value for the last encode mode to determine this
-    CODECHAL_UNSUPPORTED_MODE               = 26,
-    CODECHAL_MODE_MAX                       = 26
+    CODECHAL_ENCODE_MODE_BEGIN              = 32,
+    CODECHAL_ENCODE_MODE_AVC                = 32,   // Must be a power of 2 to match perf report expectations
+    CODECHAL_ENCODE_MODE_MPEG2              = 34,
+    CODECHAL_ENCODE_MODE_VP8                = 35,
+    CODECHAL_ENCODE_MODE_JPEG               = 36,
+    CODECHAL_ENCODE_MODE_HEVC               = 38,
+    CODECHAL_ENCODE_MODE_VP9                = 39,
+    CODECHAL_ENCODE_MODE_AV1                = 40,
+    CODECHAL_Rsvd                           = 41,
+    CODECHAL_ENCODE_MODE_END                = 42,
 
+    CODECHAL_UNSUPPORTED_MODE               = 96
 };
 
 // Slice group mask
