@@ -47,6 +47,7 @@ class MhwCpInterface;
 #define MHW_MI_DECODER_720P_WATCHDOG_THRESHOLD_IN_MS    10
 #define MHW_MI_DECODER_4K_WATCHDOG_THRESHOLD_IN_MS      20
 #define MHW_MI_DECODER_8K_WATCHDOG_THRESHOLD_IN_MS      60
+#define MHW_MI_DECODER_AV1_WATCHDOG_THRESHOLD_IN_MS     80
 #define MHW_MI_DECODER_16K_WATCHDOG_THRESHOLD_IN_MS     180
 #define MHW_MI_DECODER_16Kx16K_WATCHDOG_THRESHOLD_IN_MS 256
 #define MHW_MI_WATCHDOG_COUNTS_PER_MILLISECOND         (19200123 / 1000)   // Time stamp counts per millisecond
@@ -118,6 +119,7 @@ typedef enum _MHW_MI_ALU_OPCODE
     MHW_MI_ALU_AND = 0x102,
     MHW_MI_ALU_OR = 0x103,
     MHW_MI_ALU_XOR = 0x104,
+    MHW_MI_ALU_SHR = 0x106,
     MHW_MI_ALU_STORE = 0x180,
     MHW_MI_ALU_STOREINV = 0x580
 } MHW_MI_ALU_OPCODE;
@@ -179,6 +181,7 @@ typedef struct _MHW_PIPE_CONTROL_PARAMS
     uint32_t                bInvalidateTextureCache        : 1;
     uint32_t                bGenericMediaStateClear        : 1;
     uint32_t                bIndirectStatePointersDisable  : 1;
+    uint32_t                bUnTypedDataPortCacheFlush     : 1;
     uint32_t                bHdcPipelineFlush              : 1;
     uint32_t                bKernelFenceEnabled            : 1;
     uint32_t                bPPCFlush                      : 1;
@@ -278,11 +281,13 @@ typedef struct _MHW_MI_ATOMIC_PARAMS
 typedef struct _MHW_MI_SEMAPHORE_WAIT_PARAMS
 {
     PMOS_RESOURCE               presSemaphoreMem;        // Semaphore memory Resource
+    uint64_t                    gpuVirtualAddress;       // Semaphore memory Resource
     uint32_t                    dwResourceOffset;
     bool                        bRegisterPollMode;
     bool                        bPollingWaitMode;
     uint32_t                    dwCompareOperation;
     uint32_t                    dwSemaphoreData;
+    bool                        b64bComparEnableWithGPR;
     MHW_COMMON_MI_SEMAPHORE_COMPARE_OPERATION       CompareOperation;
 }MHW_MI_SEMAPHORE_WAIT_PARAMS, *PMHW_MI_SEMAPHORE_WAIT_PARAMS;
 
