@@ -164,8 +164,12 @@ MOS_STATUS VpAllocator::DestroySurface(MOS_SURFACE *surface, MOS_GFXRES_FREE_FLA
 {
     VP_FUNC_CALL();
     VP_PUBLIC_CHK_NULL_RETURN(m_allocator);
-
-    return m_allocator->DestroySurface(surface, flags);
+    MOS_GFXRES_FREE_FLAGS resFreeFlags = {0};
+    if (IsSyncFreeNeededForMMCSurface(surface))
+    {
+        resFreeFlags.SynchronousDestroy = 1;
+    }
+    return m_allocator->DestroySurface(surface, resFreeFlags);
 }
 
 VP_SURFACE* VpAllocator::AllocateVpSurface(MOS_ALLOC_GFXRES_PARAMS &param, bool zeroOnAllocate, VPHAL_CSPACE ColorSpace, uint32_t ChromaSiting)
@@ -736,7 +740,7 @@ MOS_STATUS VpAllocator::AllocParamsInitType(
     VP_FUNC_CALL();
     VP_PUBLIC_CHK_NULL_RETURN(surface);
 
-#if !EMUL && !LINUX
+#if !EMUL && !LINUX && !ANDROID
     //  Need to reallocate surface according to expected tiletype instead of tiletype of the surface what we have
     if ( surface                           != nullptr &&
          surface->OsResource.pGmmResInfo   != nullptr &&
@@ -848,6 +852,17 @@ MOS_STATUS VpAllocator::ReAllocateSurface(
         return eStatus;
     }
 
+    // reuse the allocated buffer if the allocated size was larger than request size when OptimizeCpuTiming is enabled
+    if (m_osInterface->bOptimizeCpuTiming                               &&
+        surface                                                         &&
+        surface->osSurface                                              &&
+        (!Mos_ResourceIsNull(&surface->osSurface->OsResource))          &&
+        (Format_Buffer                                == format)        &&
+        (surface->bufferWidth * surface->bufferHeight >= width * height))
+    {
+        return eStatus;
+    }
+
     if (surface && nullptr == surface->osSurface)
     {
         // VP_SURFACE should always be allocated by interface in VpAllocator,
@@ -984,6 +999,15 @@ MOS_STATUS VpAllocator::ReAllocateSurface(
         return eStatus;
     }
 
+    // reuse the allocated buffer if the allocated size was larger than request size when OptimizeCpuTiming is enabled
+    if (m_osInterface->bOptimizeCpuTiming                       &&
+        (!Mos_ResourceIsNull(&surface->OsResource))           &&
+        (Format_Buffer                        == format)        &&
+        (surface->dwWidth * surface->dwHeight >= width * height))
+    {
+        return eStatus;
+    }
+
     MOS_ZeroMemory(&allocParams, sizeof(MOS_ALLOC_GFXRES_PARAMS));
 
     VpHal_AllocParamsInitType(&allocParams, surface, defaultResType, defaultTileType);
@@ -1445,3 +1469,18 @@ MOS_STATUS VpAllocator::SetMmcFlags(MOS_SURFACE &osSurface)
 
     return MOS_STATUS_SUCCESS;
 }
+
+MOS_HW_RESOURCE_DEF VpAllocator::GetResourceCache(uint32_t feature, bool bOut, ENGINE_TYPE engineType, MOS_COMPONENT id)
+{
+    VP_FUNC_CALL();
+    MOS_CACHE_ELEMENT element(MOS_CODEC_RESOURCE_USAGE_BEGIN_CODEC, MOS_CODEC_RESOURCE_USAGE_BEGIN_CODEC);
+    bool              res = m_osInterface->pfnGetCacheSetting(id, SUFACE_TYPE_ASSIGNED(feature), bOut, engineType, element, false);
+    if (res == false)
+    {
+        VP_PUBLIC_ASSERTMESSAGE("Resource %u was not found in cache manager, use default usage MOS_HW_RESOURCE_USAGE_VP_INTERNAL_READ_WRITE_RENDER!", feature);
+        return MOS_HW_RESOURCE_USAGE_VP_INTERNAL_READ_WRITE_RENDER;
+    }
+
+    VP_PUBLIC_NORMALMESSAGE("Resource %u was found in cache manager, use mocs usage %u!", feature, element.mocsUsageType);
+    return element.mocsUsageType;
+}
