@@ -239,17 +239,18 @@ MOS_STATUS VpRenderHdr3DLutKernel::SetupSurfaceState()
 
     PRENDERHAL_INTERFACE renderHal   = m_hwInterface->m_renderHal;
     PMOS_INTERFACE       osInterface = m_hwInterface->m_osInterface;
-
+    m_surfaceBindingIndex.clear();
+    m_surfaceState.clear();
     KERNEL_SURFACE_STATE_PARAM kernelSurfaceParam            = {};
     // Only need to specify binding index in surface parameters.
     kernelSurfaceParam.surfaceOverwriteParams.updatedSurfaceParams = true; 
     kernelSurfaceParam.surfaceOverwriteParams.bindedKernel   = true;
     kernelSurfaceParam.surfaceOverwriteParams.bufferResource = true;
 
-    kernelSurfaceParam.surfaceOverwriteParams.bindIndex = BI_VEBOX_HDR_3DLUT_3DLUT;
+    UpdateCurbeBindingIndex(SurfaceType3DLut, BI_VEBOX_HDR_3DLUT_3DLUT);
     kernelSurfaceParam.isOutput                         = true;
     m_surfaceState.insert(std::make_pair(SurfaceType3DLut, kernelSurfaceParam));
-    kernelSurfaceParam.surfaceOverwriteParams.bindIndex = BI_VEBOX_HDR_3DLUT_COEF;
+    UpdateCurbeBindingIndex(SurfaceType3DLutCoef, BI_VEBOX_HDR_3DLUT_COEF);
     kernelSurfaceParam.isOutput                         = false;
     m_surfaceState.insert(std::make_pair(SurfaceType3DLutCoef, kernelSurfaceParam));
 
@@ -287,14 +288,18 @@ MOS_STATUS VpRenderHdr3DLutKernel::GetCurbeState(void *&curbe, uint32_t &curbeLe
 {
     VP_FUNC_CALL();
     // init the hdr 3dlut static data
+    auto bindingMap3DLut = GetSurfaceBindingIndex(SurfaceType3DLut);
+    auto bindingMapCoef  = GetSurfaceBindingIndex(SurfaceType3DLutCoef);
+    if (bindingMap3DLut.empty() || bindingMapCoef.empty())
+    {
+        VP_RENDER_CHK_STATUS_RETURN(MOS_STATUS_INVALID_PARAMETER);
+    }
+
     MOS_ZeroMemory(&m_curbe, sizeof(m_curbe));
-    m_curbe.DW00.Thread_Group_X        = LUT65_SEG_SIZE;
-    m_curbe.DW01.Thread_Group_Y        = LUT65_SEG_SIZE;
-    m_curbe.DW02.Thread_Group_Z        = 1;
-    m_curbe.DW06.hdr3DLutSurface = GetSurfaceBindingIndex(SurfaceType3DLut);
-    m_curbe.DW07.hdrCoefSurface  = GetSurfaceBindingIndex(SurfaceType3DLutCoef);
-    m_curbe.DW08.hdr3DLutSurfaceHeight = LUT65_SEG_SIZE * LUT65_MUL_SIZE;
-    m_curbe.DW08.hdr3DLutSurfaceWidth  = LUT65_SEG_SIZE * 2;
+    m_curbe.DW02.hdr3DLutSurface       = *bindingMap3DLut.begin();
+    m_curbe.DW04.hdrCoefSurface        = *bindingMapCoef.begin();
+    m_curbe.DW06.hdr3DLutSurfaceWidth  = m_hdrLutSize;
+    m_curbe.DW06.hdr3DLutSurfaceHeight = m_hdrLutSize;
 
     curbeLength = sizeof(VEBOX_HDR_3DLUT_STATIC_DATA);
     curbe = (uint8_t *) & m_curbe;
@@ -315,7 +320,7 @@ MOS_STATUS VpRenderHdr3DLutKernel::SetKernelConfigs(KERNEL_CONFIGS &kernelConfig
     PRENDER_HDR_3DLUT_CAL_PARAMS params = (PRENDER_HDR_3DLUT_CAL_PARAMS)it->second;
 
     if (m_maxDisplayLum == params->maxDisplayLum && m_maxContentLevelLum == params->maxContentLevelLum &&
-        m_hdrMode == params->hdrMode)
+        m_hdrMode == params->hdrMode && m_hdrLutSize == params->threadWidth)
     {
         // For such case, 3DLut calculation should be skipped in Policy::GetHdrExecutionCaps.
         VP_RENDER_ASSERTMESSAGE("No change in 3D Lut parameters!");
@@ -325,10 +330,12 @@ MOS_STATUS VpRenderHdr3DLutKernel::SetKernelConfigs(KERNEL_CONFIGS &kernelConfig
         m_maxDisplayLum      = params->maxDisplayLum;
         m_maxContentLevelLum = params->maxContentLevelLum;
         m_hdrMode            = params->hdrMode;
-        VP_RENDER_NORMALMESSAGE("Maximum Display Luminance %d, Maximum Content Level Luminance %d, HDR mode %d",
+        m_hdrLutSize         = params->threadWidth;
+        VP_RENDER_NORMALMESSAGE("Maximum Display Luminance %d, Maximum Content Level Luminance %d, HDR mode %d, Lut size %d",
             m_maxDisplayLum,
             m_maxContentLevelLum,
-            m_hdrMode);
+            m_hdrMode,
+            m_hdrLutSize);
     }
 
     return MOS_STATUS_SUCCESS;
@@ -340,19 +347,16 @@ MOS_STATUS VpRenderHdr3DLutKernel::GetWalkerSetting(KERNEL_WALKER_PARAMS &walker
 
     VP_FUNC_CALL();
     RENDERHAL_KERNEL_PARAM kernelSettings;
-    uint32_t               blockWidth  = 16;
-    uint32_t               blockHeight = 8;
 
     VP_RENDER_CHK_STATUS_RETURN(GetKernelSettings(kernelSettings));
     MOS_ZeroMemory(&walkerParam, sizeof(KERNEL_WALKER_PARAMS));
 
     VP_RENDER_CHK_STATUS_RETURN(VpRenderKernelObj::GetWalkerSetting(m_walkerParam, renderData));
-
-    m_walkerParam.iBlocksX          = LUT65_SEG_SIZE;
-    m_walkerParam.iBlocksY          = LUT65_SEG_SIZE;
+    m_walkerParam.iBlocksX = m_hdrLutSize;
+    m_walkerParam.iBlocksY = m_hdrLutSize;
     m_walkerParam.isVerticalPattern = false;
     m_walkerParam.bSyncFlag         = true;
-    walkerParam                     = m_walkerParam;
+    walkerParam = m_walkerParam;
     return MOS_STATUS_SUCCESS;
 }
 
@@ -423,6 +427,18 @@ MOS_STATUS VpRenderHdr3DLutKernel::InitCoefSurface(const uint32_t maxDLL, const
     return MOS_STATUS_SUCCESS;
 }
 
+MOS_STATUS VpRenderHdr3DLutKernel::SetPerfTag()
+{
+    VP_FUNC_CALL();
+    VP_RENDER_CHK_NULL_RETURN(m_hwInterface);
+    auto osInterface = m_hwInterface->m_osInterface;
+    VP_RENDER_CHK_NULL_RETURN(osInterface);
+    VP_RENDER_CHK_NULL_RETURN(osInterface->pfnSetPerfTag);
+
+    osInterface->pfnSetPerfTag(osInterface, VPHAL_EU3DLUT);
+    return MOS_STATUS_SUCCESS;
+}
+
 VpRenderHdr3DLutKernelCM::VpRenderHdr3DLutKernelCM(PVP_MHWINTERFACE hwInterface, VpKernelID kernelID, uint32_t kernelIndex, PVpAllocator allocator) : 
     VpRenderHdr3DLutKernel(hwInterface, kernelID, kernelIndex, VP_HDR_KERNEL_NAME, allocator)
 {
@@ -440,7 +456,7 @@ MOS_STATUS VpRenderHdr3DLutKernelCM::Init(VpRenderKernel &kernel)
 {
     VP_FUNC_CALL();
     m_kernelSize = kernel.GetKernelSize() + KERNEL_BINARY_PADDING_SIZE;
-
+    m_kernelPaddingSize = KERNEL_BINARY_PADDING_SIZE;
     uint8_t *pKernelBin = (uint8_t *)kernel.GetKernelBinPointer();
     VP_RENDER_CHK_NULL_RETURN(pKernelBin);
 
@@ -530,12 +546,12 @@ MOS_STATUS VpRenderHdr3DLutKernelCM::GetCurbeState(void *&curbe, uint32_t &curbe
         {
             // Resource need be added.
             uint32_t *pSurfaceindex = static_cast<uint32_t *>(arg.pData);
-            auto      it            = m_surfaceBindingIndex.find((SurfaceType)*pSurfaceindex);
-            if (it == m_surfaceBindingIndex.end())
+            auto      bindingMap    = GetSurfaceBindingIndex((SurfaceType)*pSurfaceindex);
+            if (bindingMap.empty())
             {
                 VP_RENDER_CHK_STATUS_RETURN(MOS_STATUS_INVALID_PARAMETER);
             }
-            *((uint32_t *)(data + arg.uOffsetInPayload)) = it->second;
+            *((uint32_t *)(data + arg.uOffsetInPayload)) = *bindingMap.begin();
         }
         else if (arg.eArgKind == ARG_KIND_GENERAL)
         {
@@ -560,15 +576,16 @@ MOS_STATUS VpRenderHdr3DLutKernelCM::SetupSurfaceState()
 
     PRENDERHAL_INTERFACE renderHal = m_hwInterface->m_renderHal;
     PMOS_INTERFACE osInterface = m_hwInterface->m_osInterface;
+    m_surfaceBindingIndex.clear();
 
     KERNEL_SURFACE_STATE_PARAM kernelSurfaceParam            = {};
     kernelSurfaceParam.surfaceOverwriteParams.bindedKernel   = true;
     kernelSurfaceParam.surfaceOverwriteParams.bufferResource = true;
 
-    kernelSurfaceParam.surfaceOverwriteParams.bindIndex = BI_VEBOX_HDR_3DLUT_3DLUT_CM;
+    UpdateCurbeBindingIndex(SurfaceType3DLut, BI_VEBOX_HDR_3DLUT_3DLUT_CM);
     kernelSurfaceParam.isOutput                         = true;
     m_surfaceState.insert(std::make_pair(SurfaceType3DLut, kernelSurfaceParam));
-    kernelSurfaceParam.surfaceOverwriteParams.bindIndex = BI_VEBOX_HDR_3DLUT_COEF_CM;
+    UpdateCurbeBindingIndex(SurfaceType3DLutCoef, BI_VEBOX_HDR_3DLUT_COEF_CM);
     kernelSurfaceParam.isOutput                         = false;
     m_surfaceState.insert(std::make_pair(SurfaceType3DLutCoef, kernelSurfaceParam));
     
@@ -631,3 +648,15 @@ MOS_STATUS VpRenderHdr3DLutKernelCM::SetKernelConfigs(KERNEL_CONFIGS& kernelConf
 
     return MOS_STATUS_SUCCESS;
 }
+
+MOS_STATUS VpRenderHdr3DLutKernelCM::SetPerfTag()
+{
+    VP_FUNC_CALL();
+    VP_RENDER_CHK_NULL_RETURN(m_hwInterface);
+    auto osInterface = m_hwInterface->m_osInterface;
+    VP_RENDER_CHK_NULL_RETURN(osInterface);
+    VP_RENDER_CHK_NULL_RETURN(osInterface->pfnSetPerfTag);
+
+    osInterface->pfnSetPerfTag(osInterface, VPHAL_EU3DLUT);
+    return MOS_STATUS_SUCCESS;
+}
\ No newline at end of file
