@@ -34,6 +34,7 @@
 
 #include "vp_pipeline_adapter_xe_lpm_plus.h"
 #include "vp_platform_interface_xe_lpm_plus.h"
+#include "vp_kernel_config_xe_hpg_base.h"
 #include "mhw_mi_xe_lpm_plus_base_next_impl.h"
 #include "mhw_blt_xe_lpm_plus_base_next_impl.h"
 #include "mhw_sfc_xe_lpm_plus_base_next_impl.h"
@@ -80,7 +81,6 @@ MOS_STATUS VphalInterfacesXe_Lpm_Plus::Initialize(
         *eStatus = MOS_STATUS_NULL_POINTER;
         return *eStatus;
     }
-
     InitPlatformKernelBinary(vpPlatformInterface);
 
     if (!bInitVphalState)
@@ -133,6 +133,8 @@ MOS_STATUS VphalInterfacesXe_Lpm_Plus::CreateVpPlatformInterface(
 void VphalInterfacesXe_Lpm_Plus::InitPlatformKernelBinary(
     vp::VpPlatformInterface  *&vpPlatformInterface)
 {
+    static vp::VpKernelConfigXe_Hpg_Base kernelConfig;
+    vpPlatformInterface->SetKernelConfig(&kernelConfig);
 #if defined(ENABLE_KERNELS)
     vpPlatformInterface->SetVpFCKernelBinary(
                         IGVPKRN_XE_HPG,
@@ -177,6 +179,7 @@ MOS_STATUS MhwInterfacesXe_Lpm_Plus_Next::Initialize(
     // MHW_CP and MHW_MI must always be create
     MOS_STATUS status;
     m_cpInterface = osInterface->pfnCreateMhwCpInterface(osInterface);
+    MHW_MI_CHK_NULL(m_cpInterface);
     auto ptr      = std::make_shared<mhw::mi::xe_lpm_plus_base_next::Impl>(osInterface);
     m_miItf       = std::static_pointer_cast<mhw::mi::Itf>(ptr);
     ptr->SetCpInterface(m_cpInterface, m_miItf);
@@ -351,19 +354,6 @@ MOS_STATUS McpyDeviceXe_Lpm_Plus::Initialize(
     return MOS_STATUS_SUCCESS;
 }
 
-MhwInterfacesNext* McpyDeviceXe_Lpm_Plus::CreateMhwInterface(
-    PMOS_INTERFACE osInterface)
-{
-    MhwInterfacesNext::CreateParams params;
-    params.Flags.m_vebox = true;
-    params.Flags.m_blt   = true;
-
-    // the destroy of interfaces happens when the mcpy deviced deconstructor funcs
-    MhwInterfacesNext *mhw = MhwInterfacesNext::CreateFactory(params, osInterface);
-
-    return mhw;
-}
-
 static bool mtlRegisteredCodecHal =
     MediaFactory<uint32_t, CodechalDeviceNext>::
         Register<CodechalInterfacesXe_Lpm_Plus>((uint32_t)IGFX_METEORLAKE);
@@ -408,14 +398,12 @@ MOS_STATUS CodechalInterfacesXe_Lpm_Plus::Initialize(
     if (debugInterface == nullptr)
     {
         MOS_Delete(hwInterface);
-        mhwInterfaces->SetDestroyState(true);
         CODECHAL_PUBLIC_ASSERTMESSAGE("debugInterface is not valid!");
         return MOS_STATUS_NO_SPACE;
     }
     if (debugInterface->Initialize(hwInterface, CodecFunction) != MOS_STATUS_SUCCESS)
     {
         MOS_Delete(hwInterface);
-        mhwInterfaces->SetDestroyState(true);
         MOS_Delete(debugInterface);
         CODECHAL_PUBLIC_ASSERTMESSAGE("Debug interface creation failed!");
         return MOS_STATUS_INVALID_PARAMETER;
@@ -424,6 +412,14 @@ MOS_STATUS CodechalInterfacesXe_Lpm_Plus::Initialize(
     CodechalDebugInterface *debugInterface = nullptr;
 #endif  // USE_CODECHAL_DEBUG_TOOL
 
+    auto release_func = [&]() 
+    {
+        MOS_Delete(hwInterface);
+#if USE_CODECHAL_DEBUG_TOOL
+        MOS_Delete(debugInterface);
+#endif  // USE_CODECHAL_DEBUG_TOOL
+    };
+
     if (CodecHalIsDecode(CodecFunction))
     {
 #ifdef _MPEG2_DECODE_SUPPORTED
@@ -486,7 +482,7 @@ MOS_STATUS CodechalInterfacesXe_Lpm_Plus::Initialize(
 #endif
         {
             CODECHAL_PUBLIC_ASSERTMESSAGE("Decode mode requested invalid!");
-            return MOS_STATUS_INVALID_PARAMETER;
+            CODECHAL_PUBLIC_CHK_STATUS_WITH_DESTROY_RETURN(MOS_STATUS_INVALID_PARAMETER, release_func);
         }
 
         if (m_codechalDevice == nullptr)
@@ -497,7 +493,7 @@ MOS_STATUS CodechalInterfacesXe_Lpm_Plus::Initialize(
             MOS_Delete(debugInterface);
 #endif
             CODECHAL_PUBLIC_ASSERTMESSAGE("Decoder device creation failed!");
-            return MOS_STATUS_NO_SPACE;
+            CODECHAL_PUBLIC_CHK_STATUS_WITH_DESTROY_RETURN(MOS_STATUS_NO_SPACE, release_func);
         }
     }
     else if (CodecHalIsEncode(CodecFunction))
@@ -511,14 +507,14 @@ MOS_STATUS CodechalInterfacesXe_Lpm_Plus::Initialize(
                 if (m_codechalDevice == nullptr)
                 {
                     CODECHAL_PUBLIC_ASSERTMESSAGE("Encode state creation failed!");
-                    return MOS_STATUS_INVALID_PARAMETER;
+                    CODECHAL_PUBLIC_CHK_STATUS_WITH_DESTROY_RETURN(MOS_STATUS_INVALID_PARAMETER, release_func);
                 }
                 return MOS_STATUS_SUCCESS;
             }
             else
             {
                 CODECHAL_PUBLIC_ASSERTMESSAGE("Encode allocation failed, AVC VME Encoder is not supported, please use AVC LowPower Encoder instead!");
-                return MOS_STATUS_INVALID_PARAMETER;
+                CODECHAL_PUBLIC_CHK_STATUS_WITH_DESTROY_RETURN(MOS_STATUS_INVALID_PARAMETER, release_func);
             }
         }
         else
@@ -530,7 +526,7 @@ MOS_STATUS CodechalInterfacesXe_Lpm_Plus::Initialize(
             if (m_codechalDevice == nullptr)
             {
                 CODECHAL_PUBLIC_ASSERTMESSAGE("Encode state creation failed!");
-                return MOS_STATUS_INVALID_PARAMETER;
+                CODECHAL_PUBLIC_CHK_STATUS_WITH_DESTROY_RETURN(MOS_STATUS_INVALID_PARAMETER, release_func);
             }
             return MOS_STATUS_SUCCESS;
         }
@@ -539,7 +535,7 @@ MOS_STATUS CodechalInterfacesXe_Lpm_Plus::Initialize(
         if (info->Mode == CODECHAL_ENCODE_MODE_MPEG2)
         {
             CODECHAL_PUBLIC_ASSERTMESSAGE("Encode allocation failed, MPEG2 Encoder is not supported!");
-            return MOS_STATUS_INVALID_PARAMETER;
+            CODECHAL_PUBLIC_CHK_STATUS_WITH_DESTROY_RETURN(MOS_STATUS_INVALID_PARAMETER, release_func);
         }
         else
 #ifdef _JPEG_ENCODE_SUPPORTED
@@ -549,7 +545,7 @@ MOS_STATUS CodechalInterfacesXe_Lpm_Plus::Initialize(
             if (m_codechalDevice == nullptr)
             {
                 CODECHAL_PUBLIC_ASSERTMESSAGE("Encode state creation failed!");
-                return MOS_STATUS_INVALID_PARAMETER;
+                CODECHAL_PUBLIC_CHK_STATUS_WITH_DESTROY_RETURN(MOS_STATUS_INVALID_PARAMETER, release_func);
             }
             return MOS_STATUS_SUCCESS;
         }
@@ -561,12 +557,16 @@ MOS_STATUS CodechalInterfacesXe_Lpm_Plus::Initialize(
             if (CodecHalUsesVdencEngine(info->CodecFunction))
             {
                 m_codechalDevice = MOS_New(EncodeAv1VdencPipelineAdapterXe_Lpm_Plus, hwInterface, debugInterface);
-                CODECHAL_PUBLIC_CHK_NULL_RETURN(m_codechalDevice);
+                if (m_codechalDevice == nullptr)
+                {
+                    CODECHAL_PUBLIC_ASSERTMESSAGE("Encode state creation failed!");
+                    CODECHAL_PUBLIC_CHK_STATUS_WITH_DESTROY_RETURN(MOS_STATUS_INVALID_PARAMETER, release_func);
+                }
                 return MOS_STATUS_SUCCESS;
             }
             else
             {
-                return MOS_STATUS_INVALID_PARAMETER;
+                CODECHAL_PUBLIC_CHK_STATUS_WITH_DESTROY_RETURN(MOS_STATUS_INVALID_PARAMETER, release_func);
             }
         }
         else
@@ -580,27 +580,27 @@ MOS_STATUS CodechalInterfacesXe_Lpm_Plus::Initialize(
                 if (m_codechalDevice == nullptr)
                 {
                     CODECHAL_PUBLIC_ASSERTMESSAGE("Encode state creation failed!");
-                    return MOS_STATUS_INVALID_PARAMETER;
+                    CODECHAL_PUBLIC_CHK_STATUS_WITH_DESTROY_RETURN(MOS_STATUS_INVALID_PARAMETER, release_func);
                 }
                 return MOS_STATUS_SUCCESS;
             }
             else
             {
                 CODECHAL_PUBLIC_ASSERTMESSAGE("Encode allocation failed, HEVC VME Encoder is not supported.");
-                return MOS_STATUS_INVALID_PARAMETER;
+                CODECHAL_PUBLIC_CHK_STATUS_WITH_DESTROY_RETURN(MOS_STATUS_INVALID_PARAMETER, release_func);
             }
         }
         else
 #endif
         {
             CODECHAL_PUBLIC_ASSERTMESSAGE("Unsupported encode function requested.");
-            return MOS_STATUS_INVALID_PARAMETER;
+            CODECHAL_PUBLIC_CHK_STATUS_WITH_DESTROY_RETURN(MOS_STATUS_INVALID_PARAMETER, release_func);
         }
     }
     else
     {
         CODECHAL_PUBLIC_ASSERTMESSAGE("Unsupported codec function requested.");
-        return MOS_STATUS_INVALID_PARAMETER;
+        CODECHAL_PUBLIC_CHK_STATUS_WITH_DESTROY_RETURN(MOS_STATUS_INVALID_PARAMETER, release_func);
     }
 
     return MOS_STATUS_SUCCESS;
